@@ -4,16 +4,23 @@ from .datastorage import DataStorage
 class Filesystem(DataStorage):
 
     # overriding abstract method
-    def load_dataset(self, spark, read_all=None, input_dest='', header=True):
+    def load_dataset(self, spark, read_all=False, input_dest='', header=True):
 
         if input_dest == '':
             input_dataset = self.args["input-dataset"]
         else:
             input_dataset = input_dest
+        
         delimiter = self.args["delimiter"] if "delimiter" in self.args else ","
         input_file_format = self.args["inputFileFormat"] if "inputFileFormat" in self.args else "csv"
+        
+        df = spark.read.load(input_dataset, format=input_file_format, sep=delimiter, inferSchema=True, header=header, error_bad_lines=False)
 
-        return spark.read.load(input_dataset, format=input_file_format, sep=delimiter, inferSchema=True, header=header, error_bad_lines=False)
+        if read_all == False:
+            if "input-columns" in self.args and self.args["input-columns"] != "*":
+                df = df.select(self.args["input-columns"].split(delimiter))
+
+        return df
 
     # overriding abstract method
     def save_dataset(self, df, output_dest):
